Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch/atari auxilary -> auxiliary



details:   https://anonhg.NetBSD.org/src/rev/62236ffaf5f2
branches:  trunk
changeset: 513249:62236ffaf5f2
user:      wiz <wiz%NetBSD.org@localhost>
date:      Thu Jul 26 23:07:57 2001 +0000

description:
auxilary -> auxiliary

diffstat:

 sys/arch/atari/atari/disksubr.c               |  8 ++++----
 sys/arch/atari/include/ahdilabel.h            |  6 +++---
 sys/arch/atari/include/disklabel.h            |  6 +++---
 sys/arch/atari/stand/tostools/aptck/ahdilbl.h |  6 +++---
 sys/arch/atari/stand/tostools/aptck/aptck.h   |  6 +++---
 sys/arch/atari/stand/tostools/aptck/disklbl.c |  6 +++---
 6 files changed, 19 insertions(+), 19 deletions(-)

diffs (164 lines):

diff -r 389507216d48 -r 62236ffaf5f2 sys/arch/atari/include/ahdilabel.h
--- a/sys/arch/atari/include/ahdilabel.h        Thu Jul 26 22:59:57 2001 +0000
+++ b/sys/arch/atari/include/ahdilabel.h        Thu Jul 26 23:07:57 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: ahdilabel.h,v 1.2 2001/01/07 21:05:16 leo Exp $        */
+/*     $NetBSD: ahdilabel.h,v 1.3 2001/07/26 23:07:57 wiz Exp $        */
 
 /*
  * Copyright (c) 1995 Leo Weppelman.
@@ -61,7 +61,7 @@
 #define        AHDI_MAXRPD     4               /* max. # of partition descriptors */
                                        /* in an AHDI bootblock (aka root) */
 #define        AHDI_MAXARPD    2               /* max. # of partition descriptors */
-                                       /* in an AHDI auxilary root sector */
+                                       /* in an AHDI auxiliary root sector */
 struct ahdi_part {
        u_int8_t        ap_flg;         /* bit 0 is in-use flag            */
        u_int8_t        ap_id[3];       /* id: GEM, BGM, XGM, UNX, MIX     */
@@ -86,7 +86,7 @@
 struct ahdi_ptbl {
        struct cpu_disklabel    *at_cdl;
        u_int                   at_hdsize;   /* size of volume in blocks   */
-       u_int                   at_nroots;   /* # of auxilary root sectors */
+       u_int                   at_nroots;   /* # of auxiliary root sectors */
        u_int                   at_nparts;   /* # of AHDI partitions       */
        struct ahdi_part        at_parts[AHDI_MAXPARTS];
 };
diff -r 389507216d48 -r 62236ffaf5f2 sys/arch/atari/include/disklabel.h
--- a/sys/arch/atari/include/disklabel.h        Thu Jul 26 22:59:57 2001 +0000
+++ b/sys/arch/atari/include/disklabel.h        Thu Jul 26 23:07:57 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: disklabel.h,v 1.6 2000/02/05 21:14:55 jdc Exp $        */
+/*     $NetBSD: disklabel.h,v 1.7 2001/07/26 23:07:57 wiz Exp $        */
 
 /*
  * Copyright (c) 1995 Leo Weppelman.
@@ -50,7 +50,7 @@
 #define SWAP_PART      1               /* xx?b is default swap partition  */
 #define RAW_PART       2               /* xx?c is raw partition           */
 
-#define MAXAUXROOTS    29              /* max. # of auxilary root sectors */
+#define MAXAUXROOTS    29              /* max. # of auxiliary root sectors */
 
 struct cpu_disklabel {
        u_int           cd_bblock;      /* start of NetBSD boot block      */
@@ -59,7 +59,7 @@
 #ifdef DISKLABEL_AHDI
        u_int           cd_bslst;       /* start of AHDI bad sector list   */
        u_int           cd_bslend;      /* end of AHDI bad sector list     */
-       u_int           cd_roots[MAXAUXROOTS+1]; /* auxilary root sectors  */
+       u_int           cd_roots[MAXAUXROOTS+1]; /* auxiliary root sectors  */
 #endif /* DISKLABEL_AHDI */
 };
 
diff -r 389507216d48 -r 62236ffaf5f2 sys/arch/atari/stand/tostools/aptck/ahdilbl.h
--- a/sys/arch/atari/stand/tostools/aptck/ahdilbl.h     Thu Jul 26 22:59:57 2001 +0000
+++ b/sys/arch/atari/stand/tostools/aptck/ahdilbl.h     Thu Jul 26 23:07:57 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: ahdilbl.h,v 1.2 1996/02/09 20:52:04 leo Exp $  */
+/*     $NetBSD: ahdilbl.h,v 1.3 2001/07/26 23:07:57 wiz Exp $  */
 
 /*
  * Copyright (c) 1995 Leo Weppelman.
@@ -52,7 +52,7 @@
 #define        RAW_PART        2               /* xx?c is raw partition           */
 
 #define        NO_BOOT_BLOCK   ((u_int)-1)
-#define        MAXAUXROOTS     29              /* max. # of auxilary root sectors */
+#define        MAXAUXROOTS     29              /* max. # of auxiliary root sectors */
 
 struct bootblock {
        u_int8_t        bb_xxboot[LABELOFFSET - sizeof(u_int32_t)];
@@ -98,7 +98,7 @@
 #define        AHDI_MAXRPD     4               /* max. # of partition descriptors */
                                        /* in the AHDI bootblock (aka root)*/
 #define        AHDI_MAXARPD    2               /* max. # of partition descriptors */
-                                       /* in an AHDI auxilary root sector */
+                                       /* in an AHDI auxiliary root sector */
 
 struct ahdi_part {
        u_int8_t        ap_flg;         /* bit 0 is in-use flag            */
diff -r 389507216d48 -r 62236ffaf5f2 sys/arch/atari/stand/tostools/aptck/aptck.h
--- a/sys/arch/atari/stand/tostools/aptck/aptck.h       Thu Jul 26 22:59:57 2001 +0000
+++ b/sys/arch/atari/stand/tostools/aptck/aptck.h       Thu Jul 26 23:07:57 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: aptck.h,v 1.1.1.1 1996/01/07 21:54:15 leo Exp $        */
+/*     $NetBSD: aptck.h,v 1.2 2001/07/26 23:07:57 wiz Exp $    */
 
 /*
  * Copyright (c) 1995 Waldi Ravens.
@@ -75,8 +75,8 @@
        u_int           hdsize;         /* medium size from root sector */
        u_int           bslst;          /* start of bad sector list     */
        u_int           bslend;         /* end of bad sector list       */
-       u_int           nroots;         /* # of auxilary root sectors   */
-       u_int           *roots;         /* list of auxilary roots       */
+       u_int           nroots;         /* # of auxiliary root sectors  */
+       u_int           *roots;         /* list of auxiliary roots      */
        u_int           nparts;         /* number of regular partitions */
        part_t          *parts;         /* list of partition descriptors */
 } disk_t;
diff -r 389507216d48 -r 62236ffaf5f2 sys/arch/atari/stand/tostools/aptck/disklbl.c
--- a/sys/arch/atari/stand/tostools/aptck/disklbl.c     Thu Jul 26 22:59:57 2001 +0000
+++ b/sys/arch/atari/stand/tostools/aptck/disklbl.c     Thu Jul 26 23:07:57 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: disklbl.c,v 1.3 1996/02/09 20:52:06 leo Exp $  */
+/*     $NetBSD: disklbl.c,v 1.4 2001/07/26 23:07:57 wiz Exp $  */
 
 /*
  * Copyright (c) 1995 Waldi Ravens.
@@ -265,7 +265,7 @@
                for (j = 0; j < dd->nroots; ++j) {
                        u_int   aux = dd->roots[j];
                        if (aux >= p1->start && aux <= p1->end) {
-                               printf("FATAL: auxilary root at %u\n", aux);
+                               printf("FATAL: auxiliary root at %u\n", aux);
                                rv = 1;
                        }
                }
@@ -290,7 +290,7 @@
                }
        }
 
-       printf("\nTotal number of auxilary roots: %u\n", dd->nroots);
+       printf("\nTotal number of auxiliary roots: %u\n", dd->nroots);
        printf("Total number of partitions    : %u\n", dd->nparts);
        if (dd->nparts == 0) {
                printf("* Weird # of partitions (zero) *\n"); rv = 1;



Home | Main Index | Thread Index | Old Index
diff -r 389507216d48 -r 62236ffaf5f2 sys/arch/atari/atari/disksubr.c
--- a/sys/arch/atari/atari/disksubr.c   Thu Jul 26 22:59:57 2001 +0000
+++ b/sys/arch/atari/atari/disksubr.c   Thu Jul 26 23:07:57 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: disksubr.c,v 1.21 2001/07/26 22:55:13 wiz Exp $        */
+/*     $NetBSD: disksubr.c,v 1.22 2001/07/26 23:07:57 wiz Exp $        */
 
 /*
  * Copyright (c) 1995 Leo Weppelman.
@@ -371,7 +371,7 @@
 #ifdef DISKLABEL_AHDI
 /*
  * Check for consistency between the NetBSD partition table
  * and the AHDI auxilary root sectors. There's no good reason
  * to force such consistency, but issuing a warning may help
  * an inexperienced sysadmin to prevent corruption of AHDI
  * partitions.
@@ -398,7 +398,7 @@
                        if (*rp >= p->p_offset
                          && *rp < p->p_offset + p->p_size) {
                                uprintf("Warning: NetBSD partition %c"
-                               " includes AHDI auxilary root\n", 'a'+i);
+                               " includes AHDI auxiliary root\n", 'a'+i);
                        }
                }
        }
@@ -599,7 +599,7 @@
 }
 
 /*
  * Fetch the AHDI partitions and auxilary roots.
  *
  * Returns:  0 if successful,
  *           otherwise an I/O error occurred, and the
@@ -371,7 +371,7 @@
 /*
  * Check for consistency between the NetBSD partition table
- * and the AHDI auxilary root sectors. There's no good reason
+ * and the AHDI auxiliary root sectors. There's no good reason
  * to force such consistency, but issuing a warning may help
  * an inexperienced sysadmin to prevent corruption of AHDI
@@ -599,7 +599,7 @@
 
 /*
- * Fetch the AHDI partitions and auxilary roots.
+ * Fetch the AHDI partitions and auxiliary roots.
  *
  * Returns:  0 if successful,